==> webkit2gtk_2.48.6.orig.tar.xz: webkitgtk-2.48.6/Source/WebKit/UIProcess/QueryPermissionResultCallback.h <==
/*
 * Copyright (C) 2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "APIObject.h"
#include <WebCore/PermissionState.h>
#include <wtf/CompletionHandler.h>

namespace WebKit {

class QueryPermissionResultCallback : public API::ObjectImpl<API::Object::Type::QueryPermissionResultCallback> {
public:
    static Ref<QueryPermissionResultCallback> create(CompletionHandler<void(std::optional<WebCore::PermissionState>)>&& completionHandler)
    {
        return adoptRef(*new QueryPermissionResultCallback(WTFMove(completionHandler)));
    }
    ~QueryPermissionResultCallback()
    {
        if (m_completionHandler)
            m_completionHandler({ });
    }
    void setPermission(WebCore::PermissionState permission) { m_completionHandler(permission); }

private:
    explicit QueryPermissionResultCallback(CompletionHandler<void(std::optional<WebCore::PermissionState>)>&& completionHandler)
        : m_completionHandler(WTFMove(completionHandler))
    { }

    CompletionHandler<void(std::optional<WebCore::PermissionState>)> m_completionHandler;
};

} // namespace WebKit

==> webkit2gtk_2.50.2.orig.tar.xz: webkitgtk-2.50.2/Source/WebKit/UIProcess/QueryPermissionResultCallback.h <==
/*
 * Copyright (C) 2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "APIObject.h"
#include <WebCore/PermissionState.h>
#include <wtf/CompletionHandler.h>

namespace WebKit {

class QueryPermissionResultCallback : public API::ObjectImpl<API::Object::Type::QueryPermissionResultCallback> {
public:
    static Ref<QueryPermissionResultCallback> create(CompletionHandler<void(std::optional<WebCore::PermissionState>)>&& completionHandler)
    {
        return adoptRef(*new QueryPermissionResultCallback(WTFMove(completionHandler)));
    }
    ~QueryPermissionResultCallback()
    {
        if (m_completionHandler)
            m_completionHandler({ });
    }
    void setPermission(WebCore::PermissionState permission) { m_completionHandler(permission); }

private:
    explicit QueryPermissionResultCallback(CompletionHandler<void(std::optional<WebCore::PermissionState>)>&& completionHandler)
        : m_completionHandler(WTFMove(completionHandler))
    { }

    CompletionHandler<void(std::optional<WebCore::PermissionState>)> m_completionHandler;
};

} // namespace WebKit

SPECIALIZE_TYPE_TRAITS_BEGIN(WebKit::QueryPermissionResultCallback)
static bool isType(const API::Object& object) { return object.type() == API::Object::Type::QueryPermissionResultCallback; }
SPECIALIZE_TYPE_TRAITS_END()
